# AscenderFramework CLI

CLI for interacting with core [framework](https://github.com/AscenderTeam/AscenderFramework) functionality.
This CLI allows users to create new AscenderFramework projects, as well as manage existing projects running their CLI.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)

## Installation

To install the CLI, run the following command:

```bash
pip install ascender
```

## Usage

To create new project, just execute the following command:

```bash
ascender projects new --name <project_name>
```

To execute project commands, just execute the following command:

```bash
ascender run <command>
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[GPLv3](https://choosealicense.com/licenses/gpl-3.0/)
